function [A5, b5, ctype5] = MBKS_zostav_obmedzenie_typ5(n, m, z, pocet_neznamych_celkom, KN, delta)
% Funkcia pre zostavenie subcasti matice obmedzeni A, subcasti vektoru
% pravych stran b a subcasti vektoru znakov ctype pre piate zavazne
% obmedzenie
% 
% Volanie
%   [A5, b5, ctype5] = MBKS_zostav_obmedzenie_typ5(n, m, z, pocet_neznamych_celkom, KN, delta)
% Vstup:
%   n - pocet sestier
%   m - pocet dni planovaneho obdobia
%   z - pocet smien
%   pocet_neznamych_celkom - celkovy pocet neznamych pre zavazne aj nezavazne poziadavky
%   KN - mnozina nocnych smien
%   delta - koeficient nocnej smeny
% Výstup:
%   A5 - subcast matice obmedzeni A
%   b5 - subcast vektoru pravych stran b
%   ctype5 - subcast vektoru znakov ctype
%% ABOUT
% Funkcia MBKS_zostav_obmedzenie_typ5 si zavola vstupne premenne zo
% skriptu MBKS_vstupne_parametre. Jej vystupy budu predstavovat cast matice
% ombedzeni A, vektoru pravych stran b, a parametru ctype. 
%
% Na zaciatku si zadeklarujeme premenne pocet_obmedzeni a
% pocet_nenulovych_prvkov, potrebnych pre urcenie velkosti casti matice
% obmedzeni A5, casti vektoru pravych stran b5 a casti parametru ctype5
%
% Pomocou funkcie salloc sa allokuje A5 a nasledne pomocou sustavy
% vnorenych cyklov typu for sa bude A5 naplnat. Maticu A5 sa naplna
% postupnym prechadzanim kazdeho riadku cr a k nemu odpovedajucih stlpcov.
%
% Na zaver sa naplni cast vektoru pravych stran b5 a zvoli vhodna hodnota
% parametru ctype5

%% Deklarovanie parametrov
pocet_obmedzeni = n;
pocet_nenulovych_prvkov = m * z * pocet_obmedzeni;

%% Inicializacia casti matice obmedzeni A5
A5 = spalloc(pocet_obmedzeni, pocet_neznamych_celkom, pocet_nenulovych_prvkov);

%% Naplnenie casti matice obmedzeni A5
cr = 1; % Cislo 1. riadku matice
for i = 1:n
    for j = 1:m
        for k = 1:z
            vysledok = ismember(k, KN); % premenna, do ktorej vyhodnocuje ci k sa nachadza v KN pomocou fcie ismember
            if vysledok == 1            % v pripade hodnoty True, znamena ze k je z mnoziny KN               
                A5(cr, i + (j - 1) * n + (k - 1) * m * n) = (1 - delta); 
            else                        % v pripade hodnoty True, znamena ze k je z mnoziny KN   
                A5(cr, i + (j - 1) * n + (k - 1) * m * n) = (- delta);
            end
        end
    end
    cr = cr + 1; % posun na dalsi riadok matice A5
end

%% Naplnenie casti vektoru pravych stran b5 a casti parametru ctype5
b5 = zeros(pocet_obmedzeni, 1); % Naplnenie casti vektoru pravych stran b5
ctype5(1:pocet_obmedzeni) = 'L'; % v obmedzeniach sa objavuju nerovnosti >=, preto hodnota U

end